==> libksysguard-5.20.4-1-armv6h.pkg.tar.xz: usr/lib/cmake/KSysGuard/KSysGuardLibraryTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KSysGuard::Formatter" for configuration ""
set_property(TARGET KSysGuard::Formatter APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KSysGuard::Formatter PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKSysGuardFormatter.so.5.20.4"
  IMPORTED_SONAME_NOCONFIG "libKSysGuardFormatter.so.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS KSysGuard::Formatter )
list(APPEND _IMPORT_CHECK_FILES_FOR_KSysGuard::Formatter "${_IMPORT_PREFIX}/lib/libKSysGuardFormatter.so.5.20.4" )

# Import target "KSysGuard::LsofUi" for configuration ""
set_property(TARGET KSysGuard::LsofUi APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KSysGuard::LsofUi PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/liblsofui.so.5.20.4"
  IMPORTED_SONAME_NOCONFIG "liblsofui.so.9"
  )

list(APPEND _IMPORT_CHECK_TARGETS KSysGuard::LsofUi )
list(APPEND _IMPORT_CHECK_FILES_FOR_KSysGuard::LsofUi "${_IMPORT_PREFIX}/lib/liblsofui.so.5.20.4" )

# Import target "KSysGuard::ProcessCore" for configuration ""
set_property(TARGET KSysGuard::ProcessCore APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KSysGuard::ProcessCore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n;KF5::AuthCore;KF5::CoreAddons;KF5::Service"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libprocesscore.so.5.20.4"
  IMPORTED_SONAME_NOCONFIG "libprocesscore.so.9"
  )

list(APPEND _IMPORT_CHECK_TARGETS KSysGuard::ProcessCore )
list(APPEND _IMPORT_CHECK_FILES_FOR_KSysGuard::ProcessCore "${_IMPORT_PREFIX}/lib/libprocesscore.so.5.20.4" )

# Import target "KSysGuard::ProcessUi" for configuration ""
set_property(TARGET KSysGuard::ProcessUi APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KSysGuard::ProcessUi PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::DBus;KF5::I18n;KF5::WindowSystem;KF5::AuthCore;KF5::Completion;KF5::ConfigWidgets;KF5::WidgetsAddons;KF5::IconThemes;KF5::JobWidgets;KF5::GlobalAccel;KF5::Service;KF5::KIOGui;Qt5::X11Extras"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libprocessui.so.5.20.4"
  IMPORTED_SONAME_NOCONFIG "libprocessui.so.9"
  )

list(APPEND _IMPORT_CHECK_TARGETS KSysGuard::ProcessUi )
list(APPEND _IMPORT_CHECK_FILES_FOR_KSysGuard::ProcessUi "${_IMPORT_PREFIX}/lib/libprocessui.so.5.20.4" )

# Import target "KSysGuard::Sensors" for configuration ""
set_property(TARGET KSysGuard::Sensors APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KSysGuard::Sensors PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::Core;Qt5::DBus;KF5::I18n"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKSysGuardSensors.so.5.20.4"
  IMPORTED_SONAME_NOCONFIG "libKSysGuardSensors.so.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS KSysGuard::Sensors )
list(APPEND _IMPORT_CHECK_FILES_FOR_KSysGuard::Sensors "${_IMPORT_PREFIX}/lib/libKSysGuardSensors.so.5.20.4" )

# Import target "KSysGuard::SensorFaces" for configuration ""
set_property(TARGET KSysGuard::SensorFaces APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KSysGuard::SensorFaces PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::Core;Qt5::DBus;KF5::I18n;KF5::Package;KF5::Declarative"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKSysGuardSensorFaces.so.5.20.4"
  IMPORTED_SONAME_NOCONFIG "libKSysGuardSensorFaces.so.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS KSysGuard::SensorFaces )
list(APPEND _IMPORT_CHECK_FILES_FOR_KSysGuard::SensorFaces "${_IMPORT_PREFIX}/lib/libKSysGuardSensorFaces.so.5.20.4" )

# Import target "KSysGuard::SignalPlotter" for configuration ""
set_property(TARGET KSysGuard::SignalPlotter APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KSysGuard::SignalPlotter PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KSysGuard::ProcessCore"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libksignalplotter.so.5.20.4"
  IMPORTED_SONAME_NOCONFIG "libksignalplotter.so.9"
  )

list(APPEND _IMPORT_CHECK_TARGETS KSysGuard::SignalPlotter )
list(APPEND _IMPORT_CHECK_FILES_FOR_KSysGuard::SignalPlotter "${_IMPORT_PREFIX}/lib/libksignalplotter.so.5.20.4" )

# Import target "KSysGuard::SysGuard" for configuration ""
set_property(TARGET KSysGuard::SysGuard APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KSysGuard::SysGuard PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n;KF5::CoreAddons;KSysGuard::ProcessCore"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libksgrd.so.5.20.4"
  IMPORTED_SONAME_NOCONFIG "libksgrd.so.9"
  )

list(APPEND _IMPORT_CHECK_TARGETS KSysGuard::SysGuard )
list(APPEND _IMPORT_CHECK_FILES_FOR_KSysGuard::SysGuard "${_IMPORT_PREFIX}/lib/libksgrd.so.5.20.4" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> libksysguard-5.21.2-1-armv6h.pkg.tar.xz: usr/lib/cmake/KSysGuard/KSysGuardLibraryTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KSysGuard::Formatter" for configuration ""
set_property(TARGET KSysGuard::Formatter APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KSysGuard::Formatter PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKSysGuardFormatter.so.5.21.2"
  IMPORTED_SONAME_NOCONFIG "libKSysGuardFormatter.so.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS KSysGuard::Formatter )
list(APPEND _IMPORT_CHECK_FILES_FOR_KSysGuard::Formatter "${_IMPORT_PREFIX}/lib/libKSysGuardFormatter.so.5.21.2" )

# Import target "KSysGuard::LsofUi" for configuration ""
set_property(TARGET KSysGuard::LsofUi APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KSysGuard::LsofUi PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/liblsofui.so.5.21.2"
  IMPORTED_SONAME_NOCONFIG "liblsofui.so.9"
  )

list(APPEND _IMPORT_CHECK_TARGETS KSysGuard::LsofUi )
list(APPEND _IMPORT_CHECK_FILES_FOR_KSysGuard::LsofUi "${_IMPORT_PREFIX}/lib/liblsofui.so.5.21.2" )

# Import target "KSysGuard::ProcessCore" for configuration ""
set_property(TARGET KSysGuard::ProcessCore APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KSysGuard::ProcessCore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n;KF5::AuthCore;KF5::CoreAddons;KF5::Service"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libprocesscore.so.5.21.2"
  IMPORTED_SONAME_NOCONFIG "libprocesscore.so.9"
  )

list(APPEND _IMPORT_CHECK_TARGETS KSysGuard::ProcessCore )
list(APPEND _IMPORT_CHECK_FILES_FOR_KSysGuard::ProcessCore "${_IMPORT_PREFIX}/lib/libprocesscore.so.5.21.2" )

# Import target "KSysGuard::ProcessUi" for configuration ""
set_property(TARGET KSysGuard::ProcessUi APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KSysGuard::ProcessUi PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::DBus;KF5::I18n;KF5::WindowSystem;KF5::AuthCore;KF5::Completion;KF5::ConfigWidgets;KF5::WidgetsAddons;KF5::IconThemes;KF5::JobWidgets;KF5::GlobalAccel;KF5::Service;KF5::KIOGui;Qt5::X11Extras"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libprocessui.so.5.21.2"
  IMPORTED_SONAME_NOCONFIG "libprocessui.so.9"
  )

list(APPEND _IMPORT_CHECK_TARGETS KSysGuard::ProcessUi )
list(APPEND _IMPORT_CHECK_FILES_FOR_KSysGuard::ProcessUi "${_IMPORT_PREFIX}/lib/libprocessui.so.5.21.2" )

# Import target "KSysGuard::Sensors" for configuration ""
set_property(TARGET KSysGuard::Sensors APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KSysGuard::Sensors PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::Core;Qt5::DBus;KF5::I18n"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKSysGuardSensors.so.5.21.2"
  IMPORTED_SONAME_NOCONFIG "libKSysGuardSensors.so.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS KSysGuard::Sensors )
list(APPEND _IMPORT_CHECK_FILES_FOR_KSysGuard::Sensors "${_IMPORT_PREFIX}/lib/libKSysGuardSensors.so.5.21.2" )

# Import target "KSysGuard::SensorFaces" for configuration ""
set_property(TARGET KSysGuard::SensorFaces APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KSysGuard::SensorFaces PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::Core;Qt5::DBus;KF5::I18n;KF5::Package;KF5::Declarative;KF5::Solid"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKSysGuardSensorFaces.so.5.21.2"
  IMPORTED_SONAME_NOCONFIG "libKSysGuardSensorFaces.so.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS KSysGuard::SensorFaces )
list(APPEND _IMPORT_CHECK_FILES_FOR_KSysGuard::SensorFaces "${_IMPORT_PREFIX}/lib/libKSysGuardSensorFaces.so.5.21.2" )

# Import target "KSysGuard::SignalPlotter" for configuration ""
set_property(TARGET KSysGuard::SignalPlotter APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KSysGuard::SignalPlotter PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KSysGuard::ProcessCore"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libksignalplotter.so.5.21.2"
  IMPORTED_SONAME_NOCONFIG "libksignalplotter.so.9"
  )

list(APPEND _IMPORT_CHECK_TARGETS KSysGuard::SignalPlotter )
list(APPEND _IMPORT_CHECK_FILES_FOR_KSysGuard::SignalPlotter "${_IMPORT_PREFIX}/lib/libksignalplotter.so.5.21.2" )

# Import target "KSysGuard::SysGuard" for configuration ""
set_property(TARGET KSysGuard::SysGuard APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KSysGuard::SysGuard PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n;KF5::CoreAddons;KSysGuard::ProcessCore"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libksgrd.so.5.21.2"
  IMPORTED_SONAME_NOCONFIG "libksgrd.so.9"
  )

list(APPEND _IMPORT_CHECK_TARGETS KSysGuard::SysGuard )
list(APPEND _IMPORT_CHECK_FILES_FOR_KSysGuard::SysGuard "${_IMPORT_PREFIX}/lib/libksgrd.so.5.21.2" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
